--- procps-2.0.7/sysctl.c.error	Thu Mar 22 11:51:24 2001
+++ procps-2.0.7/sysctl.c	Thu Mar 22 11:54:27 2001
@@ -53,6 +53,7 @@
 const char *PROC_PATH = "/proc/sys/";
 const char *DEFAULT_PRELOAD = "/etc/sysctl.conf";
 static bool PrintName;
+static bool IgnoreError;
 
 /* error messages */
 const char *ERR_UNKNOWN_PARAMETER = "error: Unknown parameter '%s'\n";
@@ -79,6 +80,7 @@
 const char *preloadfile = DEFAULT_PRELOAD;
 
    PrintName = true;
+   IgnoreError = false;
 
    if (argc < 2) {
        return Usage(me);
@@ -92,6 +94,9 @@
          case 'n':
               PrintName = false;
            break;
+	 case 'e':
+	      IgnoreError = true;
+	   break;	 
          case 'w':
               SwitchesAllowed = false;
               WriteMode = true;
@@ -220,7 +225,8 @@
 
       sprintf(buffer, "%s=%s", name, value);
       i = WriteSetting(buffer);
-      rc = rc ? rc : i;
+      if (!IgnoreError)
+	     rc = rc ? rc : i;
    } /* endwhile */
 
    fclose(fp);
@@ -283,7 +289,8 @@
    if (!fp) {
       switch(errno) {
       case ENOENT:
-         fprintf(stderr, ERR_INVALID_KEY, outname);
+	 if (!IgnoreError)
+		fprintf(stderr, ERR_INVALID_KEY, outname);
         break;
       case EACCES:
          fprintf(stderr, ERR_PERMISSION_DENIED, outname);
@@ -292,7 +299,10 @@
          fprintf(stderr, ERR_UNKNOWN_WRITING, errno, outname);
         break;
       } /* end switch */
-      rc = -1;
+      if (IgnoreError)
+	     rc = 0;
+      else
+	     rc = -1;
    } else {
       fprintf(fp, "%s\n", value);
       fclose(fp);
--- procps-2.0.7/sysctl.8.error	Thu Mar 22 11:53:25 2001
+++ procps-2.0.7/sysctl.8	Thu Mar 22 11:54:48 2001
@@ -10,15 +10,15 @@
 .SH NAME
 sysctl \- configure kernel parameters at runtime
 .SH SYNOPSIS
-.B "sysctl [-n] variable ..."
+.B "sysctl [-n] [-e] variable ..."
 .br
-.B "sysctl [-n] -w variable=value ..."
+.B "sysctl [-n] [-e] -w variable=value ..."
 .br
-.B "sysctl [-n] -p <filename>    (default /etc/sysctl.conf)"
+.B "sysctl [-n] [-e] -p <filename>    (default /etc/sysctl.conf)"
 .br
-.B "sysctl [-n] -a"
+.B "sysctl [-n] [-e] -a"
 .br
-.B "sysctl [-n] -A"
+.B "sysctl [-n] [-e] -A"
 .SH DESCRIPTION
 .B sysctl
 is used to modify kernel parameters at runtime.  The parameters available
@@ -41,6 +41,9 @@
 .TP
 .B "-n"
 Use this option to disable printing of the key name when printing values.
+.TP
+.B "-e"
+Use this option to ignore errors about unknown keys.
 .TP
 .B "-w"
 Use this option when you want to change a sysctl setting.
